import { __awaiter, __generator } from "tslib";
import { expect } from 'chai';
import nock from 'nock';
import { LocalStorage } from 'node-localstorage';
import { CachedStorageStrategy, DataCapsule, LocalStorageStrategy, WixStorageStrategy, } from '../src';
describe('data-capsule', function () {
    describe('with localstorage strategy', function () {
        beforeEach(function () {
            global.localStorage = new LocalStorage('./scratch');
            global.document = { cookie: '_wixCIDX=wixUser' };
        });
        afterEach(function () {
            global.localStorage.clear();
        });
        it('should store and retrieve information', function () { return __awaiter(void 0, void 0, void 0, function () {
            var capsule, _a;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        capsule = new DataCapsule({ strategy: new LocalStorageStrategy() });
                        return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix' })];
                    case 1:
                        _b.sent();
                        _a = expect;
                        return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                    case 2:
                        _a.apply(void 0, [_b.sent()]).to.equal(123);
                        return [2 /*return*/];
                }
            });
        }); });
        it('should cache items when setting items', function () { return __awaiter(void 0, void 0, void 0, function () {
            var capsule, _a;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        capsule = new DataCapsule({
                            strategy: new CachedStorageStrategy({
                                remoteStrategy: new WixStorageStrategy(),
                            }),
                        });
                        nock('http://localhost')
                            .post('/_api/wix-user-preferences-webapp/set', {
                            nameSpace: 'wix',
                            key: 'shahata',
                            blob: 123,
                        })
                            .reply(200);
                        return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix' })];
                    case 1:
                        _b.sent();
                        _a = expect;
                        return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                    case 2:
                        _a.apply(void 0, [_b.sent()]).to.equal(123);
                        return [2 /*return*/];
                }
            });
        }); });
        it('should throw if non BaseStorage is passed', function () {
            expect(function () { return new DataCapsule({ strategy: {} }); }).to.throw('must extend BaseStorage');
        });
    });
});
//# sourceMappingURL=data-capsule.spec.js.map