import { __awaiter, __generator } from "tslib";
import { expect } from 'chai';
import nock from 'nock';
import { LocalStorage } from 'node-localstorage';
import sinon from 'sinon';
import { CachedStorageStrategy, LocalStorageCachedCapsule, NOT_FOUND, WixStorageStrategy, } from '../../src';
describe('cached-storage-strategy', function () {
    beforeEach(function () {
        global.localStorage = new LocalStorage('./scratch');
        global.document = { cookie: '_wixCIDX=wixUser' };
    });
    afterEach(function () {
        global.localStorage.clear();
    });
    it('should cache items when setting items', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = LocalStorageCachedCapsule({
                        remoteStrategy: new WixStorageStrategy(),
                    });
                    nock('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/set', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        blob: 123,
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix' })];
                case 1:
                    _b.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should cache items per user', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule1, capsule2, _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    global.document = { cookie: '_wixCIDX=userId1' };
                    capsule1 = LocalStorageCachedCapsule({
                        remoteStrategy: new WixStorageStrategy(),
                    });
                    nock('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/set', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        blob: 123,
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule1.setItem('shahata', 123, { namespace: 'wix' })];
                case 1:
                    _c.sent();
                    global.document = { cookie: '_wixCIDX=userId2' };
                    capsule2 = LocalStorageCachedCapsule({
                        remoteStrategy: new WixStorageStrategy(),
                    });
                    nock('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/set', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        blob: 456,
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule2.setItem('shahata', 456, { namespace: 'wix' })];
                case 2:
                    _c.sent();
                    global.document = { cookie: '_wixCIDX=userId1' };
                    _a = expect;
                    return [4 /*yield*/, capsule1.getItem('shahata', { namespace: 'wix' })];
                case 3:
                    _a.apply(void 0, [_c.sent()]).to.equal(123);
                    global.document = { cookie: '_wixCIDX=userId2' };
                    _b = expect;
                    return [4 /*yield*/, capsule2.getItem('shahata', { namespace: 'wix' })];
                case 4:
                    _b.apply(void 0, [_c.sent()]).to.equal(456);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should query server if item is not in cache', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = LocalStorageCachedCapsule({
                        remoteStrategy: new WixStorageStrategy(),
                    });
                    nock('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefForKey/wix/shahata')
                        .reply(200, { shahata: 123 });
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 1:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should cache items when getting items', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    capsule = LocalStorageCachedCapsule({
                        remoteStrategy: new WixStorageStrategy(),
                    });
                    nock('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefForKey/wix/shahata')
                        .reply(200, { shahata: 123 });
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 1:
                    _a.apply(void 0, [_c.sent()]).to.equal(123);
                    _b = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 2:
                    _b.apply(void 0, [_c.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should cache items only for one hour', function () { return __awaiter(void 0, void 0, void 0, function () {
        var clock, capsule, _a, _b, _c;
        return __generator(this, function (_d) {
            switch (_d.label) {
                case 0:
                    clock = sinon.useFakeTimers();
                    capsule = LocalStorageCachedCapsule({
                        remoteStrategy: new WixStorageStrategy(),
                    });
                    nock('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefForKey/wix/shahata')
                        .reply(200, { shahata: 123 });
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 1:
                    _a.apply(void 0, [_d.sent()]).to.equal(123);
                    clock.tick(3600000);
                    nock('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefForKey/wix/shahata')
                        .reply(200, { shahata: 123 });
                    _b = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 2:
                    _b.apply(void 0, [_d.sent()]).to.equal(123);
                    _c = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 3:
                    _c.apply(void 0, [_d.sent()]).to.equal(123);
                    clock.restore();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should cache items when getting all items', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    capsule = LocalStorageCachedCapsule({
                        remoteStrategy: new WixStorageStrategy(),
                    });
                    nock('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefs/wix')
                        .reply(200, { shahata: 123 });
                    _a = expect;
                    return [4 /*yield*/, capsule.getAllItems({ namespace: 'wix' })];
                case 1:
                    _a.apply(void 0, [_c.sent()]).to.eql({
                        shahata: 123,
                    });
                    _b = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 2:
                    _b.apply(void 0, [_c.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should cache also the knowledge about inexistence of items', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = LocalStorageCachedCapsule({
                        remoteStrategy: new WixStorageStrategy(),
                    });
                    nock('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefForKey/wix/shahata')
                        .reply(404);
                    return [4 /*yield*/, expect(capsule.getItem('shahata', { namespace: 'wix' })).to.be.rejectedWith(NOT_FOUND)];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, expect(capsule.getItem('shahata', { namespace: 'wix' })).to.be.rejectedWith(NOT_FOUND)];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should cache also the knowledge about removal of items', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = LocalStorageCachedCapsule({
                        remoteStrategy: new WixStorageStrategy(),
                    });
                    nock('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/delete', {
                        nameSpace: 'wix',
                        key: 'shahata',
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule.removeItem('shahata', { namespace: 'wix' })];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, expect(capsule.getItem('shahata', { namespace: 'wix' })).to.be.rejectedWith(NOT_FOUND)];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should throw if non BaseStorage is passed', function () {
        expect(function () { return new CachedStorageStrategy({}); }).to.throw('must extend BaseStorage');
        expect(function () {
            return new CachedStorageStrategy({
                remoteStrategy: new WixStorageStrategy(),
                localStrategy: {},
            });
        }).to.throw('must extend BaseStorage');
    });
    describe('local cache ignorance', function () {
        beforeEach(function () {
            global.localStorage.clear();
            global.document = { cookie: '' };
        });
        it('ignores in case cannot retrieve user id', function () { return __awaiter(void 0, void 0, void 0, function () {
            var capsule, _a;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        capsule = LocalStorageCachedCapsule({
                            remoteStrategy: new WixStorageStrategy(),
                        });
                        nock('http://localhost')
                            .post('/_api/wix-user-preferences-webapp/set', {
                            nameSpace: 'wix',
                            key: 'shahata',
                            blob: 123,
                        })
                            .reply(200);
                        nock('http://localhost')
                            .get('/_api/wix-user-preferences-webapp/getVolatilePrefForKey/wix/shahata')
                            .reply(200, { shahata: 456 });
                        return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix' })];
                    case 1:
                        _b.sent();
                        _a = expect;
                        return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                    case 2:
                        _a.apply(void 0, [_b.sent()]).to.equal(456);
                        return [2 /*return*/];
                }
            });
        }); });
    });
});
//# sourceMappingURL=cached-storage.spec.js.map