import { expect } from 'chai';
import { FrameStorageListener } from '../../src';
describe('frame-storage-listener', function () {
    it('should throw if non BaseStorage is passed', function () {
        expect(function () { return new FrameStorageListener({}); }).to.throw('must extend BaseStorage');
    });
    it('should throw if a verifier is not passed', function () {
        var listener = new FrameStorageListener();
        try {
            listener.start();
            throw new Error();
        }
        catch (e) {
            expect(e.message).to.equal('start function must get a verifier function as a first argument');
        }
    });
    it('should throw if the passed verifier is not a function', function () {
        var listener = new FrameStorageListener();
        try {
            listener.start('hey-ho');
            throw new Error();
        }
        catch (e) {
            expect(e.message).to.equal('start function must get a verifier function as a first argument');
        }
    });
    it('should throw if the passed interceptor is not a function', function () {
        var listener = new FrameStorageListener();
        try {
            listener.start(function () { }, 'hey-ho');
            throw new Error();
        }
        catch (e) {
            expect(e.message).to.equal('the interceptor must be a function');
        }
    });
});
//# sourceMappingURL=frame-storage-listener.spec.js.map