import { __assign, __awaiter, __generator } from "tslib";
import { expect } from 'chai';
import { LocalStorage } from 'node-localstorage';
import sinon from 'sinon';
import { COOKIE_CONSENT_DISALLOWED, LOCAL_STORAGE_UNSUPPORTED, LocalStorageCapsule, NOT_FOUND, } from '../../src';
describe('localstorage-strategy', function () {
    beforeEach(function () {
        global.localStorage = new LocalStorage('./scratch');
    });
    afterEach(function () {
        global.localStorage && global.localStorage.clear();
    });
    it('should store and retrieve information', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = LocalStorageCapsule();
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix' })];
                case 1:
                    _b.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should throw if no namespace in setItem', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = LocalStorageCapsule();
                    return [4 /*yield*/, expect(capsule.setItem('shahata', 123)).to.eventually.rejectedWith('namespace is required')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should throw if no namespace in getItem', function () {
        var capsule = LocalStorageCapsule();
        expect(function () { return capsule.getItem('shahata'); }).to.throw('namespace is required');
    });
    it('should throw if namespace is not a string', function () {
        var capsule = LocalStorageCapsule();
        expect(function () {
            return capsule.getItem('shahata', { namespace: 123 });
        }).to.throw('namespace is required and should be a string');
    });
    it('should accept namespace in capsule constructor', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = LocalStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata', 123)];
                case 1:
                    _b.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata')];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should store namespaces in isolation', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    capsule = LocalStorageCapsule();
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix1' })];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, capsule.setItem('shahata', 456, { namespace: 'wix2' })];
                case 2:
                    _c.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix1' })];
                case 3:
                    _a.apply(void 0, [_c.sent()]).to.equal(123);
                    _b = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix2' })];
                case 4:
                    _b.apply(void 0, [_c.sent()]).to.equal(456);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should optionally pass a scope for additional isolation', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    capsule = LocalStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { scope: 'wix1' })];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, capsule.setItem('shahata', 456, { scope: 'wix2' })];
                case 2:
                    _c.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { scope: 'wix1' })];
                case 3:
                    _a.apply(void 0, [_c.sent()]).to.equal(123);
                    _b = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { scope: 'wix2' })];
                case 4:
                    _b.apply(void 0, [_c.sent()]).to.equal(456);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should allow scope to be an object', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    capsule = LocalStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { scope: { key: 'wix1' } })];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, capsule.setItem('shahata', 456, { scope: { key: 'wix2' } })];
                case 2:
                    _c.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { scope: { key: 'wix1' } })];
                case 3:
                    _a.apply(void 0, [_c.sent()]).to.equal(123);
                    _b = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { scope: { key: 'wix2' } })];
                case 4:
                    _b.apply(void 0, [_c.sent()]).to.equal(456);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should optionally pass a scope in constructor', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = LocalStorageCapsule({
                        namespace: 'wix',
                        scope: 'scope',
                    });
                    return [4 /*yield*/, capsule.setItem('shahata', 123)];
                case 1:
                    _b.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { scope: 'scope' })];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should result in rejection if item is not found', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = LocalStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, expect(capsule.getItem('shahata')).to.be.rejectedWith(NOT_FOUND)];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should treat expiration as not found', function () { return __awaiter(void 0, void 0, void 0, function () {
        var clock, capsule;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    clock = sinon.useFakeTimers();
                    capsule = LocalStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { expiration: 2 })];
                case 1:
                    _a.sent();
                    clock.tick(2000);
                    return [4 /*yield*/, expect(capsule.getItem('shahata')).to.be.rejectedWith(NOT_FOUND)];
                case 2:
                    _a.sent();
                    clock.restore();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should remove item', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = LocalStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata', 123)];
                case 1:
                    _b.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getItem('shahata')];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [4 /*yield*/, capsule.removeItem('shahata')];
                case 3:
                    _b.sent();
                    return [4 /*yield*/, expect(capsule.getItem('shahata')).to.be.rejectedWith(NOT_FOUND)];
                case 4:
                    _b.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get all items', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = LocalStorageCapsule({
                        namespace: 'wix',
                        scope: 'scope',
                    });
                    return [4 /*yield*/, capsule.setItem('shahata1', 123)];
                case 1:
                    _b.sent();
                    return [4 /*yield*/, capsule.setItem('shahata2', 456)];
                case 2:
                    _b.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getAllItems()];
                case 3:
                    _a.apply(void 0, [_b.sent()]).to.eql({
                        shahata1: 123,
                        shahata2: 456,
                    });
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get all items filtering other namespaces/scopes', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = LocalStorageCapsule({
                        namespace: 'wix',
                        scope: 'scope',
                    });
                    return [4 /*yield*/, capsule.setItem('shahata1', 123)];
                case 1:
                    _b.sent();
                    return [4 /*yield*/, capsule.setItem('shahata2', 456, { namespace: 'wix1' })];
                case 2:
                    _b.sent();
                    return [4 /*yield*/, capsule.setItem('shahata3', 789, { scope: 'scope1' })];
                case 3:
                    _b.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getAllItems()];
                case 4:
                    _a.apply(void 0, [_b.sent()]).to.eql({ shahata1: 123 });
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get all items when user controls filtering', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a, _b;
        return __generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    capsule = LocalStorageCapsule();
                    return [4 /*yield*/, capsule.setItem('shahata', 1, { namespace: 'wix1' })];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, capsule.setItem('shahata', 2, { namespace: 'wix1', scope: 'scope1' })];
                case 2:
                    _c.sent();
                    return [4 /*yield*/, capsule.setItem('shahata', 3, { namespace: 'wix1', scope: 'scope2' })];
                case 3:
                    _c.sent();
                    return [4 /*yield*/, capsule.setItem('shahata', 4, { namespace: 'wix2', scope: 'scope1' })];
                case 4:
                    _c.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getAllItems({ namespace: 'wix1', scope: 'scope1' })];
                case 5:
                    _a.apply(void 0, [_c.sent()]).to.eql({ shahata: 2 });
                    _b = expect;
                    return [4 /*yield*/, capsule.getAllItems({ namespace: 'wix1' })];
                case 6:
                    _b.apply(void 0, [_c.sent()]).to.eql({
                        shahata: 1,
                    });
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get all items filtering expired', function () { return __awaiter(void 0, void 0, void 0, function () {
        var clock, capsule, _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    clock = sinon.useFakeTimers();
                    capsule = LocalStorageCapsule({
                        namespace: 'wix',
                        scope: 'scope',
                    });
                    return [4 /*yield*/, capsule.setItem('shahata1', 123)];
                case 1:
                    _b.sent();
                    return [4 /*yield*/, capsule.setItem('shahata2', 456, { expiration: 2 })];
                case 2:
                    _b.sent();
                    clock.tick(2000);
                    _a = expect;
                    return [4 /*yield*/, capsule.getAllItems()];
                case 3:
                    _a.apply(void 0, [_b.sent()]).to.eql({ shahata1: 123 });
                    clock.restore();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should accept json scope', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = LocalStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata', 1, { scope: { userId: 123 } })];
                case 1:
                    _b.sent();
                    _a = expect;
                    return [4 /*yield*/, capsule.getAllItems({ scope: { userId: 123 } })];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.eql({
                        shahata: 1,
                    });
                    return [2 /*return*/];
            }
        });
    }); });
    it('should reject if get from local storage fails', function () { return __awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = LocalStorageCapsule({ namespace: 'wix' });
                    global.localStorage = undefined;
                    return [4 /*yield*/, expect(capsule.getItem('shahata')).to.be.rejectedWith(LOCAL_STORAGE_UNSUPPORTED)];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    describe('cookie consent', function () {
        var allowedCategories = ['analytics', 'functional'];
        var APIs = [
            [
                'global',
                function () { return mockConsentPolicyManagerGlobal(allowedCategories); },
            ],
            [
                'js sdk',
                function () { return mockConsentPolicyManagerWixSdk(allowedCategories); },
            ],
        ];
        APIs.forEach(function (_a) {
            var name = _a[0], mock = _a[1];
            describe("with " + name + " API", function () {
                mock();
                it('allows setting in case category is listed', function () { return __awaiter(void 0, void 0, void 0, function () {
                    var capsule, _a;
                    return __generator(this, function (_b) {
                        switch (_b.label) {
                            case 0:
                                capsule = LocalStorageCapsule({ namespace: 'wix' });
                                return [4 /*yield*/, capsule.setItem('key', 1, { category: 'functional' })];
                            case 1:
                                _b.sent();
                                _a = expect;
                                return [4 /*yield*/, capsule.getAllItems()];
                            case 2:
                                _a.apply(void 0, [_b.sent()]).to.eql({
                                    key: 1,
                                });
                                return [2 /*return*/];
                        }
                    });
                }); });
                it('disallows setting in case category is unlisted', function () { return __awaiter(void 0, void 0, void 0, function () {
                    var capsule;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                capsule = LocalStorageCapsule({ namespace: 'wix' });
                                return [4 /*yield*/, expect(capsule.setItem('key', 1, { category: 'advertising' })).to.eventually.be.rejectedWith(COOKIE_CONSENT_DISALLOWED)];
                            case 1:
                                _a.sent();
                                return [2 /*return*/];
                        }
                    });
                }); });
                it('allows setting in case category is not passed', function () { return __awaiter(void 0, void 0, void 0, function () {
                    var capsule, _a;
                    return __generator(this, function (_b) {
                        switch (_b.label) {
                            case 0:
                                capsule = LocalStorageCapsule({ namespace: 'wix' });
                                return [4 /*yield*/, capsule.setItem('key', 1)];
                            case 1:
                                _b.sent();
                                _a = expect;
                                return [4 /*yield*/, capsule.getAllItems()];
                            case 2:
                                _a.apply(void 0, [_b.sent()]).to.eql({
                                    key: 1,
                                });
                                return [2 /*return*/];
                        }
                    });
                }); });
            });
        });
        it('rejects in case category is unknown', function () { return __awaiter(void 0, void 0, void 0, function () {
            var capsule;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        capsule = LocalStorageCapsule({ namespace: 'wix' });
                        return [4 /*yield*/, expect(capsule.setItem('key', 1, { category: 'foo' })).to.eventually.be.rejectedWith(/category must be one of/)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); });
        it('allows any try to set an item if no consent policy manager exists', function () { return __awaiter(void 0, void 0, void 0, function () {
            var capsule, _a;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        capsule = LocalStorageCapsule({ namespace: 'wix' });
                        return [4 /*yield*/, capsule.setItem('key', 1, { category: 'essential' })];
                    case 1:
                        _b.sent();
                        return [4 /*yield*/, capsule.setItem('key2', 1, { category: 'functional' })];
                    case 2:
                        _b.sent();
                        _a = expect;
                        return [4 /*yield*/, capsule.getAllItems()];
                    case 3:
                        _a.apply(void 0, [_b.sent()]).to.eql({
                            key: 1,
                            key2: 1,
                        });
                        return [2 /*return*/];
                }
            });
        }); });
    });
});
function mockConsentPolicyManagerGlobal(categories) {
    beforeEach(function () {
        global.consentPolicyManager = {
            getCurrentConsentPolicy: function () { return ({ policy: toPolicy(categories) }); },
        };
    });
    afterEach(function () {
        delete global.consentPolicyManager;
    });
}
function mockConsentPolicyManagerWixSdk(categories) {
    beforeEach(function () {
        global.Wix = {
            Utils: {
                getCurrentConsentPolicy: function () { return ({ policy: toPolicy(categories) }); },
            },
        };
    });
    afterEach(function () {
        delete global.consentPolicyManager;
    });
}
function toPolicy(categories) {
    var defaults = {
        functional: false,
        analytics: false,
        advertising: false,
        essential: false,
    };
    return categories.reduce(function (policy, category) {
        var _a;
        return __assign(__assign(__assign({}, defaults), policy), (_a = {}, _a[category] = true, _a));
    }, {});
}
//# sourceMappingURL=local-storage.spec.js.map