"use strict";
/* global consentPolicyManager, Wix */
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyConsentPolicyCategoryIfExists = exports.verifyConsentPolicy = void 0;
var constants_1 = require("./utils/constants");
var CONSENT_POLICY_CATEGORIES = [
    'essential',
    'functional',
    'analytics',
    'advertising',
];
function verifyConsentPolicy(category) {
    verifyConsentPolicyCategoryIfExists(category);
    var policy = getConsentPolicy();
    if (typeof policy !== 'undefined' && !policy[category]) {
        throw constants_1.COOKIE_CONSENT_DISALLOWED;
    }
}
exports.verifyConsentPolicy = verifyConsentPolicy;
function verifyConsentPolicyCategoryIfExists(category) {
    if (!category) {
        return;
    }
    if (CONSENT_POLICY_CATEGORIES.indexOf(category) === -1) {
        var categories = CONSENT_POLICY_CATEGORIES.map(function (v) { return "'" + v + "'"; }).join(', ');
        throw new Error("category must be one of " + categories);
    }
}
exports.verifyConsentPolicyCategoryIfExists = verifyConsentPolicyCategoryIfExists;
function getConsentPolicy() {
    var policy = (resolveByNativeAPI() || resolveByJsSDK() || none()).policy;
    return policy;
}
function resolveByNativeAPI() {
    return (typeof consentPolicyManager === 'object' &&
        consentPolicyManager.getCurrentConsentPolicy &&
        consentPolicyManager.getCurrentConsentPolicy());
}
function resolveByJsSDK() {
    return (typeof Wix === 'object' &&
        Wix.Utils &&
        Wix.Utils.getCurrentConsentPolicy &&
        Wix.Utils.getCurrentConsentPolicy());
}
function none() {
    return {};
}
//# sourceMappingURL=consent-policy.js.map