"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var nock_1 = tslib_1.__importDefault(require("nock"));
var node_localstorage_1 = require("node-localstorage");
var src_1 = require("../src");
describe('data-capsule', function () {
    describe('with localstorage strategy', function () {
        beforeEach(function () {
            global.localStorage = new node_localstorage_1.LocalStorage('./scratch');
            global.document = { cookie: '_wixCIDX=wixUser' };
        });
        afterEach(function () {
            global.localStorage.clear();
        });
        it('should store and retrieve information', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
            var capsule, _a;
            return tslib_1.__generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        capsule = new src_1.DataCapsule({ strategy: new src_1.LocalStorageStrategy() });
                        return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix' })];
                    case 1:
                        _b.sent();
                        _a = chai_1.expect;
                        return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                    case 2:
                        _a.apply(void 0, [_b.sent()]).to.equal(123);
                        return [2 /*return*/];
                }
            });
        }); });
        it('should cache items when setting items', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
            var capsule, _a;
            return tslib_1.__generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        capsule = new src_1.DataCapsule({
                            strategy: new src_1.CachedStorageStrategy({
                                remoteStrategy: new src_1.WixStorageStrategy(),
                            }),
                        });
                        nock_1.default('http://localhost')
                            .post('/_api/wix-user-preferences-webapp/set', {
                            nameSpace: 'wix',
                            key: 'shahata',
                            blob: 123,
                        })
                            .reply(200);
                        return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix' })];
                    case 1:
                        _b.sent();
                        _a = chai_1.expect;
                        return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                    case 2:
                        _a.apply(void 0, [_b.sent()]).to.equal(123);
                        return [2 /*return*/];
                }
            });
        }); });
        it('should throw if non BaseStorage is passed', function () {
            chai_1.expect(function () { return new src_1.DataCapsule({ strategy: {} }); }).to.throw('must extend BaseStorage');
        });
    });
});
//# sourceMappingURL=data-capsule.spec.js.map