"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var src_1 = require("../../src");
var protractor_1 = require("protractor");
var switchToIFrame = function () {
    return protractor_1.browser.switchTo().frame(protractor_1.element(protractor_1.by.tagName('iframe')).getWebElement());
};
var switchToMainFrame = function () { return protractor_1.browser.switchTo().frame(null); };
describe('frame-storage-strategy connectionMaxTimeout', function () {
    var timeout = 10;
    beforeEach(function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.get("http://localhost:3000")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    LocalStorageStrategy = DataCapsuleTools.LocalStorageStrategy;\n    FrameStorageListener = DataCapsuleTools.FrameStorageListener;\n    listener = new FrameStorageListener(new LocalStorageStrategy());\n    ")];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, switchToIFrame()];
                case 3:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    DataCapsule = DataCapsuleTools.DataCapsule;\n    FrameStorageStrategy = DataCapsuleTools.FrameStorageStrategy;\n    capsule = new DataCapsule({strategy: new FrameStorageStrategy(window.top, '*', 'secret', {connectionMaxTimeout: '" + timeout + "'})});\n    ")];
                case 4:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    afterEach(function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, switchToMainFrame()];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("localStorage.clear();")];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should not store and retrieve information as timeout is too short', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var result;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.executeScript("\n    capsule.setItem('hey', 'ho', {namespace: 'wix'})\n      .then(() => capsule.getItem('hey', {namespace: 'wix'}))\n      .then((result) => {\n        const text = window.document.createTextNode(result);\n        window.document.querySelector('#result').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode('FAILURE '+e.message);\n        window.document.querySelector('#result').appendChild(text);\n      });\n    ")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.findElement(protractor_1.by.id('result')).getText()];
                case 2:
                    result = _a.sent();
                    chai_1.expect(result).to.equal("FAILURE max timeout of " + timeout + "ms exceeded");
                    return [2 /*return*/];
            }
        });
    }); });
});
describe('frame-storage-strategy', function () {
    beforeEach(function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.get("http://localhost:3000")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    LocalStorageStrategy = DataCapsuleTools.LocalStorageStrategy;\n    FrameStorageListener = DataCapsuleTools.FrameStorageListener;\n    listener = new FrameStorageListener(new LocalStorageStrategy());\n    listener.start((source, origin, token) => token === 'secret');\n    ")];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, switchToIFrame()];
                case 3:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    DataCapsule = DataCapsuleTools.DataCapsule;\n    FrameStorageStrategy = DataCapsuleTools.FrameStorageStrategy;\n    capsule = new DataCapsule({strategy: new FrameStorageStrategy(window.top, '*', 'secret')});\n    ")];
                case 4:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    afterEach(function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, switchToMainFrame()];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("localStorage.clear();")];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should store and retrieve information', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var result;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.executeScript("\n    capsule.setItem('hey', 'ho', {namespace: 'wix'})\n      .then(() => capsule.getItem('hey', {namespace: 'wix'}))\n      .then((result) => {\n        const text = window.document.createTextNode(result);\n        window.document.querySelector('#result').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode('FAILURE');\n        window.document.querySelector('#result').appendChild(text);\n      });\n    ")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.findElement(protractor_1.by.id('result')).getText()];
                case 2:
                    result = _a.sent();
                    chai_1.expect(result).to.equal('ho');
                    return [2 /*return*/];
            }
        });
    }); });
    it('should remove items (and handle rejections)', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var result;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.executeScript("\n    capsule.setItem('hey', 'ho', {namespace: 'wix'})\n      .then(() => capsule.removeItem('hey', {namespace: 'wix'}))\n      .then(() => capsule.getItem('hey', {namespace: 'wix'}))\n      .then((result) => {\n        const text = window.document.createTextNode(result);\n        window.document.querySelector('#result').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode(e.toString());\n        window.document.querySelector('#result').appendChild(text);\n      });\n    ")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.findElement(protractor_1.by.id('result')).getText()];
                case 2:
                    result = _a.sent();
                    chai_1.expect(result).to.equal(src_1.NOT_FOUND.toString());
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get all items', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var result;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.executeScript("\n    capsule.setItem('hey', 'ho', {namespace: 'wix'})\n      .then(() => capsule.getAllItems({namespace: 'wix'}))\n      .then((result) => {\n        const text = window.document.createTextNode(JSON.stringify(result));\n        window.document.querySelector('#result').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode(e.toString());\n        window.document.querySelector('#result').appendChild(text);\n      });\n    ")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.findElement(protractor_1.by.id('result')).getText()];
                case 2:
                    result = _a.sent();
                    chai_1.expect(result).to.equal('{"hey":"ho"}');
                    return [2 /*return*/];
            }
        });
    }); });
    it("should stop the listener when calling the 🛑 method, and therefore the message won't return", function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var result;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, switchToMainFrame()];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("listener.stop()")];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, switchToIFrame()];
                case 3:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    capsule.setItem('hey', 'ho', {namespace: 'wix'})\n      .then(() => capsule.getItem('hey', {namespace: 'wix'}))\n      .then((result) => {\n        const text = window.document.createTextNode(result);\n        window.document.querySelector('#result').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode('FAILURE');\n        window.document.querySelector('#result').appendChild(text);\n      });\n    ")];
                case 4:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.findElement(protractor_1.by.id('result')).getText()];
                case 5:
                    result = _a.sent();
                    chai_1.expect(result).to.equal('');
                    return [2 /*return*/];
            }
        });
    }); });
});
describe('frame-storage-strategy when the token is different', function () {
    beforeEach(function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.get("http://localhost:3000")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    LocalStorageStrategy = DataCapsuleTools.LocalStorageStrategy;\n    FrameStorageListener = DataCapsuleTools.FrameStorageListener;\n    listener = new FrameStorageListener(new LocalStorageStrategy());\n    listener.start((source, origin, token) => token === 'secret');\n    ")];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, switchToIFrame()];
                case 3:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    DataCapsule = DataCapsuleTools.DataCapsule;\n    FrameStorageStrategy = DataCapsuleTools.FrameStorageStrategy;\n    capsule = new DataCapsule({strategy: new FrameStorageStrategy(window.top, '*', 'different-then-secret')});\n    ")];
                case 4:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    afterEach(function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, switchToMainFrame()];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("localStorage.clear();")];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should send a not authorized message when the message was not authorized by the listener verifier', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var result;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: 
                // notice that the token in the capsule is different then the token in the listener
                return [4 /*yield*/, protractor_1.browser.executeScript("\n    capsule.setItem('hey', 'ho', {namespace: 'wix'})\n      .then(() => {\n        const text = window.document.createTextNode('SUCCESS');\n        window.document.querySelector('#result').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode(e.toString());\n        window.document.querySelector('#result').appendChild(text);\n      });\n    ")];
                case 1:
                    // notice that the token in the capsule is different then the token in the listener
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.findElement(protractor_1.by.id('result')).getText()];
                case 2:
                    result = _a.sent();
                    chai_1.expect(result).to.equal(new Error('message was not authorized').toString());
                    return [2 /*return*/];
            }
        });
    }); });
});
describe('frame-storage-strategy when there is a interceptor', function () {
    beforeEach(function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.get("http://localhost:3000")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    LocalStorageStrategy = DataCapsuleTools.LocalStorageStrategy;\n    FrameStorageListener = DataCapsuleTools.FrameStorageListener;\n    listener = new FrameStorageListener(new LocalStorageStrategy());\n    listener.start(\n      (source, origin, token) => token === 'secret',\n      (options, source, origin, token) => {\n          options.namespace = 'custom-space';\n          options.scope = 'custom-scope';\n          return options;\n        }\n  );\n    ")];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, switchToIFrame()];
                case 3:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    DataCapsule = DataCapsuleTools.DataCapsule;\n    FrameStorageStrategy = DataCapsuleTools.FrameStorageStrategy;\n    capsule = new DataCapsule({strategy: new FrameStorageStrategy(window.top, '*', 'secret')});\n    ")];
                case 4:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    afterEach(function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, switchToMainFrame()];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("localStorage.clear();")];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should save the item on a different scope and namespace as described in the listener', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var result, a;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.executeScript("\n    capsule.setItem('hey', 'ho', {namespace: 'wix'})\n      .then(() => capsule.getItem('hey', {namespace: 'custom-space', scope: 'custom-scope'}))\n      .then((result) => {\n        const text = window.document.createTextNode(result);\n        window.document.querySelector('#result').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode('FAILURE');\n        window.document.querySelector('#result').appendChild(text);\n      });\n    ")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.findElement(protractor_1.by.id('result')).getText()];
                case 2:
                    result = _a.sent();
                    chai_1.expect(result).to.equal('ho');
                    return [4 /*yield*/, switchToMainFrame()];
                case 3:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("return localStorage.getItem('capsule|custom-space|custom-scope#hey')")];
                case 4:
                    a = _a.sent();
                    chai_1.expect(JSON.parse(a).value).to.equal('ho');
                    return [2 /*return*/];
            }
        });
    }); });
});
describe('frame-storage-strategy with custom host strategy', function () {
    beforeEach(function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.get("http://localhost:3000")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    class MyStorageStrategy extends DataCapsuleTools.BaseStorage {\n      setItem() {\n        return Promise.reject(new Error('byebye'));\n      }\n      getItem() {\n        //\n      }\n      removeItem() {\n        //\n      }\n      getAllItems() {\n        //\n      }\n    }\n\n    FrameStorageListener = DataCapsuleTools.FrameStorageListener;\n    listener = new FrameStorageListener(new MyStorageStrategy());\n    listener.start((source, origin, token) => token === 'secret');\n    ")];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, switchToIFrame()];
                case 3:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("\n    DataCapsule = DataCapsuleTools.DataCapsule;\n    FrameStorageStrategy = DataCapsuleTools.FrameStorageStrategy;\n    capsule = new DataCapsule({strategy: new FrameStorageStrategy(window.top, '*', 'secret')});\n    ")];
                case 4:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    afterEach(function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, switchToMainFrame()];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.executeScript("localStorage.clear();")];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should allow for custom errors to be transmitted over the wire', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var result;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, protractor_1.browser.executeScript("\n    capsule.setItem('hey', 'ho', {namespace: 'wix'})\n      .then(() => capsule.getItem('hey', {namespace: 'wix'}))\n      .then((result) => {\n        const text = window.document.createTextNode('SUCCESS');\n        window.document.querySelector('#result').appendChild(text);\n      })\n      .catch((e) => {\n        const text = window.document.createTextNode(e.toString());\n        window.document.querySelector('#result').appendChild(text);\n      });\n    ")];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, protractor_1.browser.findElement(protractor_1.by.id('result')).getText()];
                case 2:
                    result = _a.sent();
                    chai_1.expect(result).to.equal(new Error('byebye').toString());
                    return [2 /*return*/];
            }
        });
    }); });
});
//# sourceMappingURL=frame-storage.e2e.js.map