"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var chai_1 = require("chai");
var src_1 = require("../../src");
describe('in-memory-strategy', function () {
    it('should store and retrieve information', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = src_1.InMemoryStorageCapsule();
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix' })];
                case 1:
                    _b.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should throw if no namespace in setItem', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = src_1.InMemoryStorageCapsule();
                    return [4 /*yield*/, chai_1.expect(capsule.setItem('shahata', 123)).to.eventually.rejectedWith('namespace is required')];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should throw if no namespace in getItem', function () {
        var capsule = src_1.InMemoryStorageCapsule();
        chai_1.expect(function () { return capsule.getItem('shahata'); }).to.throw('namespace is required');
    });
    it('should throw if namespace is not a string', function () {
        var capsule = src_1.InMemoryStorageCapsule();
        chai_1.expect(function () {
            return capsule.getItem('shahata', { namespace: 123 });
        }).to.throw('namespace is required and should be a string');
    });
    it('should accept namespace in capsule constructor', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = src_1.InMemoryStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata', 123)];
                case 1:
                    _b.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('shahata')];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should store namespaces in isolation', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a, _b;
        return tslib_1.__generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    capsule = src_1.InMemoryStorageCapsule();
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix1' })];
                case 1:
                    _c.sent();
                    return [4 /*yield*/, capsule.setItem('shahata', 456, { namespace: 'wix2' })];
                case 2:
                    _c.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix1' })];
                case 3:
                    _a.apply(void 0, [_c.sent()]).to.equal(123);
                    _b = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix2' })];
                case 4:
                    _b.apply(void 0, [_c.sent()]).to.equal(456);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should result in rejection if item is not found', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = src_1.InMemoryStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, chai_1.expect(capsule.getItem('shahata')).to.be.rejectedWith(src_1.NOT_FOUND)];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get a boolean false value', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = src_1.InMemoryStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata', false)];
                case 1:
                    _b.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('shahata')];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.equal(false);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should remove item', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = src_1.InMemoryStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata', 123)];
                case 1:
                    _b.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('shahata')];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [4 /*yield*/, capsule.removeItem('shahata')];
                case 3:
                    _b.sent();
                    return [4 /*yield*/, chai_1.expect(capsule.getItem('shahata')).to.be.rejectedWith(src_1.NOT_FOUND)];
                case 4:
                    _b.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get all items', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = src_1.InMemoryStorageCapsule({
                        namespace: 'wix',
                        scope: 'scope',
                    });
                    return [4 /*yield*/, capsule.setItem('shahata1', 123)];
                case 1:
                    _b.sent();
                    return [4 /*yield*/, capsule.setItem('shahata2', 456)];
                case 2:
                    _b.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getAllItems()];
                case 3:
                    _a.apply(void 0, [_b.sent()]).to.eql({
                        shahata1: 123,
                        shahata2: 456,
                    });
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get all items filtering other namespaces', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = src_1.InMemoryStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata1', 123)];
                case 1:
                    _b.sent();
                    return [4 /*yield*/, capsule.setItem('shahata2', 456, { namespace: 'wix1' })];
                case 2:
                    _b.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getAllItems()];
                case 3:
                    _a.apply(void 0, [_b.sent()]).to.eql({ shahata1: 123 });
                    return [2 /*return*/];
            }
        });
    }); });
    it('should accept json scope', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = src_1.InMemoryStorageCapsule({ namespace: 'wix' });
                    return [4 /*yield*/, capsule.setItem('shahata', 1, { scope: { userId: 123 } })];
                case 1:
                    _b.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getAllItems({ scope: { userId: 123 } })];
                case 2:
                    _a.apply(void 0, [_b.sent()]).to.eql({
                        shahata: 1,
                    });
                    return [2 /*return*/];
            }
        });
    }); });
});
//# sourceMappingURL=in-memory-storage.spec.js.map