"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var sinon_1 = tslib_1.__importDefault(require("sinon"));
var chai_1 = require("chai");
var node_localstorage_1 = require("node-localstorage");
var src_1 = require("../../src");
describe('local-storage-cleaner', function () {
    var oneKilobyte = new Array(1000).fill('a').join('');
    var clock;
    beforeEach(function () {
        clock = sinon_1.default.useFakeTimers(Date.now());
        global.localStorage = new node_localstorage_1.LocalStorage('./limited', 4000); // only 4k in local storage
    });
    afterEach(function () {
        global.localStorage.clear();
        clock.restore();
    });
    it('should clean oldest records first', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a, _b;
        return tslib_1.__generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    capsule = src_1.LocalStorageCapsule({ namespace: 'w' });
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k1', oneKilobyte)];
                case 1:
                    _c.sent();
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k2', oneKilobyte)];
                case 2:
                    _c.sent();
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k3', oneKilobyte)];
                case 3:
                    _c.sent();
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k4', oneKilobyte + oneKilobyte)];
                case 4:
                    _c.sent(); // need to remove 2 old records to free up 2k
                    return [4 /*yield*/, chai_1.expect(capsule.getItem('k1')).to.be.rejectedWith(src_1.NOT_FOUND)];
                case 5:
                    _c.sent();
                    return [4 /*yield*/, chai_1.expect(capsule.getItem('k2')).to.be.rejectedWith(src_1.NOT_FOUND)];
                case 6:
                    _c.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('k3')];
                case 7:
                    _a.apply(void 0, [_c.sent()]).to.equal(oneKilobyte);
                    _b = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('k4')];
                case 8:
                    _b.apply(void 0, [_c.sent()]).to.equal(oneKilobyte + oneKilobyte);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should clean last accessed records first', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a, _b;
        return tslib_1.__generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    capsule = src_1.LocalStorageCapsule({ namespace: 'w' });
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k1', oneKilobyte)];
                case 1:
                    _c.sent();
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k2', oneKilobyte)];
                case 2:
                    _c.sent();
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k3', oneKilobyte)];
                case 3:
                    _c.sent();
                    clock.tick(1);
                    return [4 /*yield*/, capsule.getItem('k2')];
                case 4:
                    _c.sent(); // access k2 so it is not removed first
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k4', oneKilobyte + oneKilobyte)];
                case 5:
                    _c.sent();
                    return [4 /*yield*/, chai_1.expect(capsule.getItem('k1')).to.be.rejectedWith(src_1.NOT_FOUND)];
                case 6:
                    _c.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('k2')];
                case 7:
                    _a.apply(void 0, [_c.sent()]).to.equal(oneKilobyte);
                    return [4 /*yield*/, chai_1.expect(capsule.getItem('k3')).to.be.rejectedWith(src_1.NOT_FOUND)];
                case 8:
                    _c.sent();
                    _b = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('k4')];
                case 9:
                    _b.apply(void 0, [_c.sent()]).to.equal(oneKilobyte + oneKilobyte);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should clean expired records first ', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a, _b;
        return tslib_1.__generator(this, function (_c) {
            switch (_c.label) {
                case 0:
                    capsule = src_1.LocalStorageCapsule({ namespace: 'w' });
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k1', oneKilobyte)];
                case 1:
                    _c.sent();
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k2', oneKilobyte)];
                case 2:
                    _c.sent();
                    clock.tick(1);
                    return [4 /*yield*/, capsule.setItem('k3', oneKilobyte, { expiration: 2 })];
                case 3:
                    _c.sent();
                    clock.tick(2000); // k3 is expired so in addition we only remove k1 to free up 2k
                    return [4 /*yield*/, capsule.setItem('k4', oneKilobyte + oneKilobyte)];
                case 4:
                    _c.sent();
                    return [4 /*yield*/, chai_1.expect(capsule.getItem('k1')).to.be.rejectedWith(src_1.NOT_FOUND)];
                case 5:
                    _c.sent();
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('k2')];
                case 6:
                    _a.apply(void 0, [_c.sent()]).to.equal(oneKilobyte);
                    return [4 /*yield*/, chai_1.expect(capsule.getItem('k3')).to.be.rejectedWith(src_1.NOT_FOUND)];
                case 7:
                    _c.sent();
                    _b = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('k4')];
                case 8:
                    _b.apply(void 0, [_c.sent()]).to.equal(oneKilobyte + oneKilobyte);
                    return [2 /*return*/];
            }
        });
    }); });
});
//# sourceMappingURL=local-storage-cleaner.spec.js.map