"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var nock_1 = tslib_1.__importDefault(require("nock"));
var chai_1 = require("chai");
var src_1 = require("../../src");
describe('wix-storage-strategy', function () {
    it('should set item', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/set', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        blob: 123,
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix' })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('passes through signed instance as an authorization header', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var signedInstance, capsule, reqheaders;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    signedInstance = 'foo';
                    capsule = new src_1.DataCapsule({
                        strategy: new src_1.WixStorageStrategy({ signedInstance: signedInstance }),
                    });
                    reqheaders = { authorization: signedInstance };
                    nock_1.default('http://localhost', { reqheaders: reqheaders })
                        .post('/_api/wix-user-preferences-webapp/set', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        blob: 123,
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix' })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should set item with scope', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/set', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        blob: 123,
                        siteId: '456',
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule.setItem('shahata', 123, {
                            namespace: 'wix',
                            scope: { siteId: '456' },
                        })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should set item with string scope', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/set', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        blob: 123,
                        siteId: '456',
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix', scope: '456' })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should set item with expiration', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/set', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        blob: 123,
                        TTLInDays: 1,
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule.setItem('shahata', 123, { namespace: 'wix', expiration: 1 })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should set item with expiration in days', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/set', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        blob: 123,
                        TTLInDays: 2,
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule.setItem('shahata', 123, {
                            namespace: 'wix',
                            expiration: 60 * 60 * 48,
                        })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should set item with error handling', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/set', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        blob: 123,
                    })
                        .reply(500);
                    return [4 /*yield*/, chai_1.expect(capsule.setItem('shahata', 123, { namespace: 'wix' })).to.be.rejectedWith(src_1.SERVER_ERROR)];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should delete item', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/delete', {
                        nameSpace: 'wix',
                        key: 'shahata',
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule.removeItem('shahata', { namespace: 'wix' })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should delete item with scope', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/delete', {
                        nameSpace: 'wix',
                        key: 'shahata',
                        siteId: '456',
                    })
                        .reply(200);
                    return [4 /*yield*/, capsule.removeItem('shahata', {
                            namespace: 'wix',
                            scope: { siteId: '456' },
                        })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should delete item with error handling', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .post('/_api/wix-user-preferences-webapp/delete', {
                        nameSpace: 'wix',
                        key: 'shahata',
                    })
                        .reply(500);
                    return [4 /*yield*/, chai_1.expect(capsule.removeItem('shahata', { namespace: 'wix' })).to.be.rejectedWith(src_1.SERVER_ERROR)];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get item', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefForKey/wix/shahata')
                        .reply(200, { shahata: 123 });
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('shahata', { namespace: 'wix' })];
                case 1:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get item with scope', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefForSite/wix/456/shahata')
                        .reply(200, { shahata: 123 });
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getItem('shahata', {
                            namespace: 'wix',
                            scope: { siteId: '456' },
                        })];
                case 1:
                    _a.apply(void 0, [_b.sent()]).to.equal(123);
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get item with error handling', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefForKey/wix/shahata')
                        .reply(500);
                    return [4 /*yield*/, chai_1.expect(capsule.getItem('shahata', { namespace: 'wix' })).to.be.rejectedWith(src_1.SERVER_ERROR)];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get item with 404 handling', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefForKey/wix/shahata')
                        .reply(404);
                    return [4 /*yield*/, chai_1.expect(capsule.getItem('shahata', { namespace: 'wix' })).to.be.rejectedWith(src_1.NOT_FOUND)];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get items', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefs/wix')
                        .reply(200, { shahata: 123 });
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getAllItems({ namespace: 'wix' })];
                case 1:
                    _a.apply(void 0, [_b.sent()]).to.eql({
                        shahata: 123,
                    });
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get items with scope', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefsForSite/wix/456')
                        .reply(200, { shahata: 123 });
                    _a = chai_1.expect;
                    return [4 /*yield*/, capsule.getAllItems({ namespace: 'wix', scope: { siteId: '456' } })];
                case 1:
                    _a.apply(void 0, [_b.sent()]).to.eql({ shahata: 123 });
                    return [2 /*return*/];
            }
        });
    }); });
    it('should get items with error handling', function () { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var capsule;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    capsule = new src_1.DataCapsule({ strategy: new src_1.WixStorageStrategy() });
                    nock_1.default('http://localhost')
                        .get('/_api/wix-user-preferences-webapp/getVolatilePrefs/wix')
                        .reply(500);
                    return [4 /*yield*/, chai_1.expect(capsule.getAllItems({ namespace: 'wix' })).to.be.rejectedWith(src_1.SERVER_ERROR)];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    }); });
});
//# sourceMappingURL=wix-storage.spec.js.map